==> libqaccessibilityclient-0.4.0p0.tgz: lib/cmake/QAccessibilityClient/QAccessibilityClientConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QAccessibilityClientConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(Qt5Core 5.6.0)
find_dependency(Qt5Widgets 5.6.0)

# Thanks to the generated exported target, simply use qaccessibilityclient
# e.g. target_link_libraries(mytarget qaccessibilityclient)
include("${CMAKE_CURRENT_LIST_DIR}/QAccessibilityClient.cmake")

# Backward compatibility:
set(QACCESSIBILITYCLIENT_VERSION_MAJOR 0)
set(QACCESSIBILITYCLIENT_VERSION_MINOR 4)
set(QACCESSIBILITYCLIENT_VERSION_PATCH 0)
set(QACCESSIBILITYCLIENT_VERSION 0.4.0)

set(QACCESSIBILITYCLIENT_INCLUDE_DIR         "/usr/local/include")
set(QACCESSIBILITYCLIENT_LIBRARY             qaccessibilityclient-qt5)

==> libqaccessibilityclient-0.4.1.tgz: lib/cmake/QAccessibilityClient/QAccessibilityClientConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QAccessibilityClientConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(Qt5Core 5.6.0)
find_dependency(Qt5Widgets 5.6.0)

# Thanks to the generated exported target, simply use qaccessibilityclient
# e.g. target_link_libraries(mytarget qaccessibilityclient)
include("${CMAKE_CURRENT_LIST_DIR}/QAccessibilityClient.cmake")

# Backward compatibility:
set(QACCESSIBILITYCLIENT_VERSION_MAJOR 0)
set(QACCESSIBILITYCLIENT_VERSION_MINOR 4)
set(QACCESSIBILITYCLIENT_VERSION_PATCH 1)
set(QACCESSIBILITYCLIENT_VERSION 0.4.1)

get_target_property(QACCESSIBILITYCLIENT_INCLUDE_DIR qaccessibilityclient-qt5 INTERFACE_INCLUDE_DIRECTORIES)
set(QACCESSIBILITYCLIENT_LIBRARY             qaccessibilityclient-qt5)
